@@ -3,20 +3,21 @@
 
 """Defines the Error Analysis Manager class."""
 
-from pathlib import Path
 import json
+from pathlib import Path
 
-from responsibleai.exceptions import UserConfigValidationException
-from responsibleai._internal.constants import (
-    ManagerNames, ListProperties, ErrorAnalysisManagerKeys as Keys)
-from responsibleai._managers.base_manager import BaseManager
-from responsibleai._config.base_config import BaseConfig
-from responsibleai.exceptions import DuplicateManagerConfigException
-from erroranalysis._internal.error_analyzer import ModelAnalyzer
-from erroranalysis._internal.error_report import (
-    json_converter as report_json_converter, as_error_report)
 from erroranalysis._internal.constants import metric_to_display_name
+from erroranalysis._internal.error_analyzer import ModelAnalyzer
+from erroranalysis._internal.error_report import as_error_report
+from erroranalysis._internal.error_report import \
+    json_converter as report_json_converter
+from responsibleai._config.base_config import BaseConfig
 from responsibleai._interfaces import ErrorAnalysisData
+from responsibleai._internal.constants import ErrorAnalysisManagerKeys as Keys
+from responsibleai._internal.constants import ListProperties, ManagerNames
+from responsibleai._managers.base_manager import BaseManager
+from responsibleai.exceptions import (DuplicateManagerConfigException,
+                                      UserConfigValidationException)
 
 REPORTS = 'reports'
 CONFIG = 'config'
@@ -170,9 +171,15 @@ class ErrorAnalysisManager(BaseManager):
     :type dataset: pandas.DataFrame
     :param target_column: The name of the label column.
     :type target_column: str
+    :param classes: Class names as a list of strings.
+        The order of the class names should match that of the model
+        output.  Only required if analyzing a classifier.
+    :type classes: list
+    :param categorical_features: The categorical feature names.
+    :type categorical_features: list[str]
     """
 
-    def __init__(self, model, dataset, target_column,
+    def __init__(self, model, dataset, target_column, classes=None,
                  categorical_features=None):
         """Defines the ErrorAnalysisManager for discovering errors in a model.
 
@@ -184,10 +191,17 @@ class ErrorAnalysisManager(BaseManager):
         :type dataset: pandas.DataFrame
         :param target_column: The name of the label column.
         :type target_column: str
+        :param classes: Class names as a list of strings.
+            The order of the class names should match that of the model
+            output.  Only required if analyzing a classifier.
+        :type classes: list
+        :param categorical_features: The categorical feature names.
+        :type categorical_features: list[str]
         """
         self._true_y = dataset[target_column]
         self._dataset = dataset.drop(columns=[target_column])
         self._feature_names = list(self._dataset.columns)
+        self._classes = classes
         self._categorical_features = categorical_features
         self._ea_config_list = []
         self._ea_report_list = []
@@ -195,7 +209,8 @@ class ErrorAnalysisManager(BaseManager):
                                        self._dataset,
                                        self._true_y,
                                        self._feature_names,
-                                       self._categorical_features)
+                                       self._categorical_features,
+                                       classes=self._classes)
 
     def add(self, max_depth=3, num_leaves=31,
             min_child_samples=20, filter_features=None):
@@ -335,6 +350,8 @@ class ErrorAnalysisManager(BaseManager):
         :type path: str
         :param model_analysis: The loaded parent ModelAnalysis.
         :type model_analysis: ModelAnalysis
+        :return: The ErrorAnalysisManager manager after loading.
+        :rtype: ErrorAnalysisManager
         """
         # create the ErrorAnalysisManager without any properties using
         # the __new__ function, similar to pickle
