@@ -4,12 +4,10 @@
 
 import pytest
 
-from ..common_utils import (
-    create_iris_data, create_lightgbm_classifier
-)
-
 from responsibleai import ModelAnalysis
 
+from ..common_utils import create_iris_data, create_lightgbm_classifier
+
 
 class TestCounterfactualAdvancedFeatures(object):
 
@@ -70,3 +68,40 @@ class TestCounterfactualAdvancedFeatures(object):
 
         cf_obj = model_analysis.counterfactual.get()[0]
         assert cf_obj is not None
+
+    def test_counterfactual_manager_save_load(self, tmpdir):
+        X_train, X_test, y_train, y_test, feature_names, _ = \
+            create_iris_data()
+
+        model = create_lightgbm_classifier(X_train, y_train)
+        X_train['target'] = y_train
+        X_test['target'] = y_test
+
+        model_analysis = ModelAnalysis(
+            model=model,
+            train=X_train,
+            test=X_test.iloc[0:10],
+            target_column='target',
+            task_type='classification')
+
+        model_analysis.counterfactual.add(
+            total_CFs=10, desired_class=2,
+            features_to_vary=[feature_names[0]],
+            permitted_range={feature_names[0]: [2.0, 5.0]})
+        model_analysis.counterfactual.add(
+            total_CFs=10, desired_class=1,
+            features_to_vary=[feature_names[0]],
+            permitted_range={feature_names[0]: [2.0, 5.0]})
+        model_analysis.counterfactual.compute()
+
+        assert len(model_analysis.counterfactual.get()) == 2
+        cf_obj = model_analysis.counterfactual.get()[0]
+        assert cf_obj is not None
+
+        save_dir = tmpdir.mkdir('save-dir')
+        model_analysis.save(save_dir)
+        model_analysis_copy = ModelAnalysis.load(save_dir)
+
+        assert len(model_analysis_copy.counterfactual.get()) == 2
+        cf_obj = model_analysis_copy.counterfactual.get()[0]
+        assert cf_obj is not None
