@@ -1,30 +1,28 @@
 # Copyright (c) Microsoft Corporation
 # Licensed under the MIT License.
 
-import pytest
-import pandas as pd
-import numpy as np
 from pathlib import Path
 from tempfile import TemporaryDirectory
-from .common_utils import (create_boston_data,
-                           create_cancer_data,
-                           create_iris_data,
-                           create_binary_classification_dataset,
-                           create_adult_income_dataset,
-                           create_models_classification,
-                           create_complex_classification_pipeline,
-                           create_models_regression)
+
+import numpy as np
+import pandas as pd
+import pytest
 
 from responsibleai import ModelAnalysis, ModelTask
 from responsibleai._internal.constants import ManagerNames
 
 from .causal_manager_validator import validate_causal
+from .common_utils import (create_adult_income_dataset,
+                           create_binary_classification_dataset,
+                           create_boston_data, create_cancer_data,
+                           create_complex_classification_pipeline,
+                           create_iris_data, create_models_classification,
+                           create_models_regression)
 from .counterfactual_manager_validator import validate_counterfactual
-from .error_analysis_validator import (
-    setup_error_analysis, validate_error_analysis)
+from .error_analysis_validator import (setup_error_analysis,
+                                       validate_error_analysis)
 from .explainer_manager_validator import setup_explainer, validate_explainer
 
-
 LABELS = 'labels'
 
 
@@ -236,9 +234,6 @@ def run_model_analysis(model, train_data, test_data, target_column,
         # load the model_analysis
         model_analysis = ModelAnalysis.load(path)
 
-        if manager_type == ManagerNames.EXPLAINER:
-            setup_explainer(model_analysis)
-
         validate_model_analysis(
             model_analysis, train_data, test_data,
             target_column, task_type, categorical_features)
@@ -250,6 +245,9 @@ def run_model_analysis(model, train_data, test_data, target_column,
             validate_error_analysis(model_analysis, expected_reports=2)
         elif manager_type == ManagerNames.EXPLAINER:
             validate_explainer(model_analysis, train_data, test_data, classes)
+            # validate adding new explainer config after deserialization works
+            setup_explainer(model_analysis)
+            validate_explainer(model_analysis, train_data, test_data, classes)
 
 
 def validate_model_analysis(
